@@ -1,11 +1,16 @@
 ## Find frequency of each set for set size bar plot
-FindSetFreqs <- function(data, start_col, num_sets, set_names){
+FindSetFreqs <- function(data, start_col, num_sets, set_names, keep_order){
   end_col <- as.numeric(((start_col + num_sets) -1))
   temp_data <- data[ ,start_col:end_col]
   temp_data <- temp_data[set_names]
   temp_data <- as.data.frame(colSums(temp_data))
   colnames(temp_data) <- c("y")
+  if(keep_order == FALSE){
   temp_data <- temp_data[order(temp_data$y, decreasing = T), ]
+  }
+  else{
+    temp_data <- temp_data$y
+  }
   x <- seq(1:num_sets)
   temp_data <- cbind(temp_data, x)
   colnames(temp_data) <- c("y", "x")
